@@ -527,20 +527,19 @@ static void
 cb_update_editor (GogObject *gobj, ObjectPrefState *state)
 {
 	GogObjectPosition manual_size = gog_object_get_position_flags (gobj, GOG_POSITION_ANY_MANUAL_SIZE);
-	gboolean visible;
 	if (state->x_spin != NULL)
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->x_spin), gobj->manual_position.x * 100.0);
 	if (state->y_spin != NULL)
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->y_spin), gobj->manual_position.y * 100.0);
 	if (state->w_spin != NULL) {
-		visible = manual_size & GOG_POSITION_MANUAL_W;
+		gboolean visible = (manual_size & GOG_POSITION_MANUAL_W) != 0;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->w_spin), gobj->manual_position.w * 100.0);
 		gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "width_label"), visible);
 		gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "width_spin"), visible);
 		gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "width-pc-lbl"), visible);
 	}
 	if (state->h_spin != NULL) {
-		visible = manual_size & GOG_POSITION_MANUAL_H;
+		gboolean visible = (manual_size & GOG_POSITION_MANUAL_H) != 0;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->h_spin), gobj->manual_position.h * 100.0);
 		gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "height_label"), visible);
 		gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "height_spin"), visible);
@@ -578,11 +577,11 @@ cb_manual_size_changed (GtkComboBox *combo, ObjectPrefState *state)
 			break;
 		}
 	gog_object_set_position_flags (state->gobj, pos, GOG_POSITION_ANY_MANUAL_SIZE);
-	visible = pos & GOG_POSITION_MANUAL_W;
+	visible = (pos & GOG_POSITION_MANUAL_W) != 0;
 	gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "width_label"), visible);
 	gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "width_spin"), visible);
 	gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "width-pc-lbl"), visible);
-	visible = pos & GOG_POSITION_MANUAL_H;
+	visible = (pos & GOG_POSITION_MANUAL_H) != 0;
 	gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "height_label"), visible);
 	gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "height_spin"), visible);
 	gtk_widget_set_visible (go_gtk_builder_get_widget (state->gui, "height-pc-lbl"), visible);
@@ -1220,7 +1219,7 @@ gog_object_get_name (GogObject const *obj)
 /**
  * gog_object_set_name:
  * @obj: #GogObject
- * @name: The new name for @obj
+ * @name: (transfer full): The new name for @obj
  * @err: #GError
  *
  * Assign the new name and signals that it has changed.
@@ -1696,7 +1695,7 @@ gog_object_clear_parent (GogObject *obj)
 
 /**
  * gog_object_set_parent:
- * @child: #GogObject.
+ * @child: (transfer full): #GogObject.
  * @parent: #GogObject.
  * @id: optionally %NULL.
  * @role: a static string that can be sent to @parent::add
@@ -1747,7 +1746,7 @@ gog_object_set_parent (GogObject *child, GogObject *parent,
  * gog_object_add_by_role:
  * @parent: #GogObject
  * @role: #GogObjectRole
- * @child: #GogObject
+ * @child: (transfer full) (allow-none): #GogObject
  *
  * Absorb a ref to @child if it is non-NULL.
  * Returns: (transfer none): @child or a newly created object with @role.  Callers do _not_ own
@@ -1868,8 +1867,9 @@ gog_object_set_position_flags (GogObject *obj, GogObjectPosition flags, GogObjec
 	if ((flags & obj->role->allowable_positions) !=
 	    (flags & (GOG_POSITION_COMPASS | GOG_POSITION_ANY_MANUAL |
 	              GOG_POSITION_ANY_MANUAL_SIZE))) {
-		g_warning ("[GogObject::set_position_flags] Invalid flags (%s)",
-			   gog_object_get_name (obj));
+		g_warning ("[GogObject::set_position_flags] Invalid flags (%s) flags=0x%x  allowable=0x%x",
+			   gog_object_get_name (obj),
+			   flags, obj->role->allowable_positions);
 		return FALSE;
 	}
 	obj->position = (obj->position & ~mask) | (flags & mask);
@@ -1932,20 +1932,41 @@ gog_object_get_manual_allocation (GogObject *gobj,
 				  GogViewRequisition const *requisition)
 {
 	GogViewAllocation pos;
-	unsigned anchor;
+	unsigned anchor, size, expand;
 	GogManualSizeMode size_mode = gog_object_get_manual_size_mode (gobj);
 
 	pos.x = parent_allocation->x + gobj->manual_position.x * parent_allocation->w;
 	pos.y = parent_allocation->y + gobj->manual_position.y * parent_allocation->h;
 
-	pos.w = (size_mode & GOG_MANUAL_SIZE_WIDTH)?
-		gobj->manual_position.w * parent_allocation->w:
-		requisition->w;
-	pos.h = (size_mode & GOG_MANUAL_SIZE_HEIGHT)?
-		gobj->manual_position.h * parent_allocation->h:
-		requisition->h;
-
+	size = gog_object_get_position_flags (gobj, GOG_POSITION_ANY_MANUAL_SIZE);
 	anchor = gog_object_get_position_flags (gobj, GOG_POSITION_ANCHOR);
+	expand = gobj->role->allowable_positions & GOG_POSITION_EXPAND;
+
+	if ((size_mode & GOG_MANUAL_SIZE_WIDTH) &&
+	         (size & (GOG_POSITION_MANUAL_W | GOG_POSITION_MANUAL_W_ABS)))
+		pos.w = gobj->manual_position.w * parent_allocation->w;
+	else  if (expand & GOG_POSITION_HEXPAND) {
+		/* use available width */
+		switch (anchor) {
+			case GOG_POSITION_ANCHOR_N:
+			case GOG_POSITION_ANCHOR_CENTER:
+			case GOG_POSITION_ANCHOR_S:
+				pos.w = MIN (gobj->manual_position.x, 1 - gobj->manual_position.x)
+						 * 2. * parent_allocation->w;
+				break;
+			case GOG_POSITION_ANCHOR_SE:
+			case GOG_POSITION_ANCHOR_E:
+			case GOG_POSITION_ANCHOR_NE:
+				pos.w = gobj->manual_position.x * parent_allocation->w;
+				break;
+			default:
+				pos.w = (1 - gobj->manual_position.x) * parent_allocation->w;
+				break;
+		}
+		if (pos.w < requisition->w)
+			pos.w = requisition->w;
+	} else
+		pos.w = requisition->w;
 
 	switch (anchor) {
 		case GOG_POSITION_ANCHOR_N:
@@ -1961,6 +1982,31 @@ gog_object_get_manual_allocation (GogObject *gobj,
 		default:
 			break;
 	}
+	if ((size_mode & GOG_MANUAL_SIZE_HEIGHT) &&
+	         (size & (GOG_POSITION_MANUAL_H | GOG_POSITION_MANUAL_H_ABS)))
+		pos.h = gobj->manual_position.h * parent_allocation->h;
+	else  if (expand & GOG_POSITION_VEXPAND) {
+		/* use available width */
+		switch (anchor) {
+			case GOG_POSITION_ANCHOR_E:
+			case GOG_POSITION_ANCHOR_CENTER:
+			case GOG_POSITION_ANCHOR_W:
+				pos.h = MIN (gobj->manual_position.y, 1 - gobj->manual_position.y)
+						 * 2. * parent_allocation->h;
+				break;
+			case GOG_POSITION_ANCHOR_SE:
+			case GOG_POSITION_ANCHOR_S:
+			case GOG_POSITION_ANCHOR_SW:
+				pos.h = gobj->manual_position.y * parent_allocation->h;
+				break;
+			default:
+				pos.h = (1 - gobj->manual_position.y) * parent_allocation->h;
+				break;
+		}
+		if (pos.h < requisition->h)
+			pos.h = requisition->h;
+	} else
+		pos.h = requisition->h;
 	switch (anchor) {
 		case GOG_POSITION_ANCHOR_E:
 		case GOG_POSITION_ANCHOR_CENTER:
