@@ -79,16 +79,10 @@ make_icon (GtkAction *a, const char *stock_id, GtkWidget *tool)
 
 	if (stock_id == NULL)
 		return NULL;
-	if (GO_IS_TOOL_COMBO_PIXMAPS (tool)) {
-		GtkWidget *parent = gtk_widget_get_parent (tool);
-		if (parent)
-			size = gtk_toolbar_get_icon_size (GTK_TOOLBAR (parent));
-		else {
-			GtkSettings *settings = gtk_widget_get_settings (tool);
-			g_object_get (settings, "gtk-toolbar-icon-size", &size, NULL);
-		}
-	} else
-		size = GTK_ICON_SIZE_MENU;
+
+	size = GTK_IS_TOOL_ITEM (tool)
+		? gtk_tool_item_get_icon_size (GTK_TOOL_ITEM (tool))
+		: GTK_ICON_SIZE_MENU;
 
 	return gtk_widget_render_icon_pixbuf (tool, stock_id, size);
 }
@@ -135,26 +129,24 @@ cb_selection_changed (GOComboPixmaps *combo, int id, GOActionComboPixmaps *pacti
 }
 
 static void
-cb_toolbar_reconfigured (GOToolComboPixmaps *tool)
+cb_toolbar_reconfigured (GOToolComboPixmaps *tool, GtkAction *a)
 {
 	GtkOrientation o = gtk_tool_item_get_orientation (GTK_TOOL_ITEM (tool));
+	GtkReliefStyle relief = gtk_tool_item_get_relief_style (GTK_TOOL_ITEM (tool));
+	GOActionComboPixmaps *paction = (GOActionComboPixmaps *)a;
+	GOActionComboPixmapsElement const *el = paction->elements;
 
 	g_object_set (G_OBJECT (tool->combo),
 		      "show-arrow", o == GTK_ORIENTATION_HORIZONTAL,
 		      NULL);
-}
 
-static GtkWidget *
-go_action_combo_pixmaps_create_tool_item (GtkAction *a)
-{
-	GOActionComboPixmaps *paction = (GOActionComboPixmaps *)a;
-	GOToolComboPixmaps *tool = g_object_new (GO_TYPE_TOOL_COMBO_PIXMAPS, NULL);
-	GOActionComboPixmapsElement const *el = paction->elements;
-
-	tool->combo = go_combo_pixmaps_new (paction->ncols);
+	go_combo_pixmaps_clear_elements (tool->combo);
 	for ( ; el->stock_id != NULL ; el++) {
 		GdkPixbuf *icon = make_icon (a, el->stock_id, GTK_WIDGET (tool));
-/* FIXME FIXME FIXME we must find a better solution for translating strings not in goffice domain */
+		/*
+		 * FIXME FIXME FIXME: we must find a better solution for
+		 * translating strings not in goffice domain
+		 */
 		go_combo_pixmaps_add_element (tool->combo,
 					      icon,
 					      el->id,
@@ -162,12 +154,22 @@ go_action_combo_pixmaps_create_tool_item (GtkAction *a)
 	}
 	go_combo_pixmaps_select_id (tool->combo, paction->selected_id);
 
+	go_combo_box_set_relief (GO_COMBO_BOX (tool->combo), relief);
+}
+
+static GtkWidget *
+go_action_combo_pixmaps_create_tool_item (GtkAction *a)
+{
+	GOActionComboPixmaps *paction = (GOActionComboPixmaps *)a;
+	GOToolComboPixmaps *tool = g_object_new (GO_TYPE_TOOL_COMBO_PIXMAPS, NULL);
+
+	tool->combo = go_combo_pixmaps_new (paction->ncols);
+
 	g_signal_connect (tool, "toolbar-reconfigured",
 			  G_CALLBACK (cb_toolbar_reconfigured),
-			  NULL);
-	cb_toolbar_reconfigured (tool);
+			  a);
+	cb_toolbar_reconfigured (tool, a);
 
-	go_combo_box_set_relief (GO_COMBO_BOX (tool->combo), GTK_RELIEF_NONE);
 	go_gtk_widget_disable_focus (GTK_WIDGET (tool->combo));
 	gtk_container_add (GTK_CONTAINER (tool), GTK_WIDGET (tool->combo));
 	gtk_widget_show (GTK_WIDGET (tool->combo));
